'use strict';

const Promise = require('bluebird');
const Errors = require('common-errors');
const key = require('../utils/key');
const getInternalData = require('../utils/getInternalData');
const getMetadata = require('../utils/getMetadata');

var _require = require('../constants');

const USERS_INDEX = _require.USERS_INDEX;
const USERS_PUBLIC_INDEX = _require.USERS_PUBLIC_INDEX;
const USERS_ALIAS_TO_LOGIN = _require.USERS_ALIAS_TO_LOGIN;
const USERS_DATA = _require.USERS_DATA;
const USERS_METADATA = _require.USERS_METADATA;
const USERS_TOKENS = _require.USERS_TOKENS;
const USERS_ALIAS_FIELD = _require.USERS_ALIAS_FIELD;
const USERS_ADMIN_ROLE = _require.USERS_ADMIN_ROLE;


module.exports = function removeUser(_ref) {
  let username = _ref.username;

  const audience = this.config.jwt.defaultAudience;

  return Promise.props({
    internal: getInternalData.call(this, username),
    meta: getMetadata.call(this, username, audience)
  }).then(_ref2 => {
    let internal = _ref2.internal;
    let meta = _ref2.meta;

    const isAdmin = (meta[audience].roles || []).indexOf(USERS_ADMIN_ROLE) >= 0;
    if (isAdmin) {
      throw new Errors.HttpStatusError(400, 'can\'t remove admin user from the system');
    }

    const transaction = this.redis.multi();
    const alias = internal[USERS_ALIAS_FIELD];
    if (alias) {
      transaction.hdel(USERS_ALIAS_TO_LOGIN, alias);
    }

    // clean indices
    transaction.srem(USERS_PUBLIC_INDEX, username);
    transaction.srem(USERS_INDEX, username);

    // remove metadata & internal data
    transaction.del(key(username, USERS_DATA));
    transaction.del(key(username, USERS_METADATA, audience));

    // remove auth tokens
    transaction.del(key(username, USERS_TOKENS));

    // complete it
    return transaction.exec();
  });
};