'use strict';

const mapValues = require('lodash/mapValues');
const pick = require('lodash/pick');
const redisKey = require('../utils/key.js');
const Promise = require('bluebird');
const isArray = Array.isArray;

const JSONParse = JSON.parse.bind(JSON);

var _require = require('../constants.js');

const USERS_METADATA = _require.USERS_METADATA;


module.exports = function getMetadata(username, _audiences) {
  let fields = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];
  const redis = this.redis;

  const audiences = isArray(_audiences) ? _audiences : [_audiences];

  return Promise.map(audiences, audience => {
    return redis.hgetallBuffer(redisKey(username, USERS_METADATA, audience));
  }).then(function remapAudienceData(data) {
    const output = {};
    audiences.forEach(function transform(aud, idx) {
      const datum = data[idx];

      if (datum) {
        const pickFields = fields[aud];
        output[aud] = mapValues(datum, JSONParse);
        if (pickFields) {
          output[aud] = pick(output[aud], pickFields);
        }
      } else {
        output[aud] = {};
      }
    });

    return output;
  });
};